@@ -27,9 +27,9 @@ class PlayerInfo:public QFrame
 {
    Q_OBJECT
 public:
-   explicit PlayerInfo(int pnr,QWidget *parent=0);
+   explicit PlayerInfo(int pnr,QWidget *parent = nullptr);
    static void loadPixmaps();
-public slots:
+public Q_SLOTS:
    void setHitpoints(int h);
    void setEnergy(int e);
    void setWins(int w);
