@@ -24,7 +24,7 @@
 
 
 SimpleSprite::SimpleSprite(QSvgRenderer* svg, const QString& element)
-      :QGraphicsSvgItem(0)
+      :QGraphicsSvgItem(nullptr)
 {
    setSharedRenderer(svg);
    setElementId(element);
@@ -62,6 +62,8 @@ MobileSprite::MobileSprite(QSvgRenderer* svg, const QString& element, int pn)
 
 void MobileSprite::forward(double mult, int fr)
 {
+   Q_UNUSED(fr);
+
    if(!stopped)
    {
       QGraphicsSvgItem::moveBy(xVelocity()*mult,yVelocity()*mult);
